pub struct CheckUpdateResponse {
pub updates_available: Option<UpdatesAvailable>,
}Expand description
Information about updates available for system services in a cluster.
Fields
updates_available: Option<UpdatesAvailable>Yes if updates are available for the system services, No if not.
Implementations