pub struct OperationalizationClusterCredentials {
pub storage_account: Option<StorageAccountCredentials>,
pub container_registry: Option<ContainerRegistryCredentials>,
pub container_service: Option<ContainerServiceCredentials>,
pub app_insights: Option<AppInsightsCredentials>,
pub service_auth_configuration: Option<ServiceAuthConfiguration>,
pub ssl_configuration: Option<SslConfiguration>,
}Expand description
Credentials to resources in the cluster.
Fields
storage_account: Option<StorageAccountCredentials>Access information for the storage account.
container_registry: Option<ContainerRegistryCredentials>Information about the Azure Container Registry which contains the images deployed to the cluster.
container_service: Option<ContainerServiceCredentials>Information about the Azure Container Registry which contains the images deployed to the cluster.
app_insights: Option<AppInsightsCredentials>AppInsights credentials.
service_auth_configuration: Option<ServiceAuthConfiguration>Global service auth configuration properties. These are the data-plane authorization keys and are used if a service doesn’t define it’s own.
ssl_configuration: Option<SslConfiguration>SSL configuration. If configured data-plane calls to user services will be exposed over SSL only.
Implementations